@@ -1,5 +1,5 @@
 #
-#   Copyright (c) 2014-2015, 2018 eGauge Systems LLC
+#   Copyright (c) 2014-2015, 2018, 2021 eGauge Systems LLC
 # 	1644 Conestoga St, Suite 2
 # 	Boulder, CO 80301
 # 	voice: 720-545-9767
@@ -24,8 +24,9 @@ from django.core.exceptions import ObjectDoesNotExist
 from django.utils.html import escape
 from django.utils import timezone
 
+from epic.base import Enum
 from epic.compat import reverse
-from epic.models import Assembly_Item, Delta, Line_Item, Order, Part, \
+from epic.models import Assembly_Item, Delta, Line_Item, Part, \
     Part_Count, Part_Inventory, Warehouse, Transaction, \
     html_part_link
 from epic.stock_cache import Stock_Cache
@@ -234,7 +235,7 @@ def get_open_order_line_items(last_order=None):
     later than that LAST_ORDER.
 
     """
-    qs = Line_Item.objects.filter(txtn__order__status=Order.STATUS_OPEN)
+    qs = Line_Item.objects.filter(txtn__order__status=Enum.TXTN_STATUS_OPEN)
     if last_order is not None:
         qs = qs.exclude(txtn__order__expected_arrival_date__gt=\
                         last_order.expected_arrival_date)
@@ -722,14 +723,14 @@ def breadcrumb(path):
     for i, name in enumerate(comps):
         if i == 0:
             continue
+
+        path = '/'.join(comps[0:i+1])
+        if name == 'epic':
+            name = 'EPIC'
+        elif name == 'bom':
+            name = 'BOM'
         else:
-            path = '/'.join(comps[0:i+1])
-            if name == 'epic':
-                name = 'EPIC'
-            elif name == 'bom':
-                name = 'BOM'
-            else:
-                name = name.capitalize()
+            name = name.capitalize()
         if i == len(comps) - 1:
             content += '<li class="active">%s</li>' % name
         else:
